using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using SchemaBuilder = DataDynamics.Analysis.Schema;
using DataDynamics.Analysis.DataSources;
using DataDynamics.Analysis.Extensions.Schema;

namespace ddAnalysis_SQLite
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Configure Relational DataSource
            RdDataSource rddata = new RdDataSource();
            rddata.ConnectionType = ConnectionType.Odbc;
            rddata.ConnectionString="DRIVER=SQLite3 ODBC Driver;Database="+ Application.StartupPath+"\\MyTest.db;LongNames=0;Timeout=1000;NoTXN=0;SyncPragma=NORMAL;StepAPI=0;";
            rddata.QueryString = "Select Product, SalesDate, UnitPrice, Quantity from ProductSales";
            
            //configure the schema
            //autogenerate
            SchemaBuilder.SchemaBuilder sb = SchemaBuilder.SchemaBuilder.AutoGenerate("MySchema", new System.Data.Odbc.OdbcConnection(rddata.ConnectionString), rddata.QueryString);
            
            //add a query field for the calculated field
            SchemaBuilder.QueryFieldBuilder qfb = new DataDynamics.Analysis.Schema.QueryFieldBuilder("TotalSales");
            qfb.SetExpression<double>("=Fields!.UnitPrice.Value*Fields!Quantity.Value");
            sb.AddQueryField(qfb);
            
            //get a refernce to the measures dimension
            SchemaBuilder.MeasuresDimBuilder mdb = (SchemaBuilder.MeasuresDimBuilder)sb.Dimensions["Measures"];
            
            //create a new measure field to the query field previously created
            SchemaBuilder.MeasureBuilder mb = new SchemaBuilder.MeasureBuilder("TotalSales");
            mb.SetExpression<double>("=Fields!TotalSales.Value");
            
            //add the field the meansure dimension
            mdb.AddField(mb);

            //save the schema file
            sb.SaveSchema(Application.StartupPath + "\\mySchema.schema");

            //provide the Relational Data Source with the schema file
            rddata.CustomSchemaFile = Application.StartupPath + "\\mySchema.schema";
            
            //bind the datasource to the pivotview's datasource and open the connection
            this.pivotView1.DataSource = rddata;
            rddata.Connect();

            //modify the pivot views layout to display a line chart showing TotalSales over time
            SchemaDefinition schema = this.pivotView1.DataSource.Schema;
            //each method in the ILayoutActions interface returns a reference to itself
            this.pivotView1.BeginLayoutUpdate("Setup")//create the ILayoutActions instance
            .SetMarkingType(DataDynamics.Analysis.DataViewModel.MarkingType.Line)//set the encoding type
            .AppendField(schema.Get<DataDynamics.Analysis.Extensions.Schema.Attribute>("[SalesDate].[Year]"), DataDynamics.Analysis.LayoutActions.Shelf.Column)//add the year part of the date attribute field to the column shelf
            .AppendField(schema.Get<DataDynamics.Analysis.Extensions.Schema.Measure>("[Measures].[TotalSales]"), DataDynamics.Analysis.LayoutActions.Shelf.Row)//add the TotalSales measure to the row shelf
            .Commit();//commit the changes to the pivot view
        }
    }
}